@@ -1,4 +1,5 @@
 from urllib.parse import urlparse, urlunparse, urlencode, parse_qs
+from typing import AsyncIterable
 import pprint
 
 from .excs import HTTPError, AuthError, ValidationError
@@ -52,7 +53,7 @@ class MediaUpload:
 
         validate (bool): Whether or not a session should validate the upload size before sending
 
-        pipe_from (file object): class object to stream file content from
+        pipe_from (file object, AsyncIterable): class object to stream file content from
     """
 
     def __init__(
@@ -97,7 +98,11 @@ class MediaUpload:
             async for chunk in aiter_func(self.file_path, self.chunk_size):
                 yield chunk
         elif self.pipe_from:
-            yield self.pipe_from.read()
+            if isinstance(self.pipe_from, AsyncIterable):
+                async for chunk in self.pipe_from:
+                    yield chunk
+            else:
+                yield self.pipe_from.read()
         else:
             async for chunk in self._aiter_body():
                 yield chunk
@@ -273,6 +278,8 @@ class Response:
         pipe_from (file object): class object to stream file content from
 
         session_factory (aiogoogle.sessions.abc.AbstractSession): A callable implementation of aiogoogle's session interface
+        
+        auth_manager (aiogoogle.auth.managers.ServiceAccountManager): Service account authorization manager.
     """
 
     def __init__(
@@ -289,6 +296,7 @@ class Response:
         upload_file=None,
         pipe_from=None,
         session_factory=None,
+        auth_manager=None
     ):
         if json and data:
             raise TypeError("Pass either json or data, not both.")
@@ -305,6 +313,7 @@ class Response:
         self.upload_file = upload_file
         self.pipe_from = pipe_from
         self.session_factory = session_factory
+        self.auth_manager = auth_manager
 
     @staticmethod
     async def _next_page_generator(
@@ -333,7 +342,9 @@ class Response:
             )
             if next_req is not None:
                 async with session_factory() as sess:
-                    prev_res = await sess.send(next_req, full_res=True)
+                    await prev_res.auth_manager.refresh()
+                    prev_res.auth_manager.authorize(next_req)    
+                    prev_res = await sess.send(next_req, full_res=True, auth_manager=prev_res.auth_manager)
             else:
                 prev_res = None
 
